"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const launchers_1 = require("./launchers");
const utils_1 = require("./utils");
function chooseLauncher(options) {
    const { split, terminalApp } = options;
    const platform = process.platform;
    const isWindows = /^win/.test(platform);
    const isMac = /darwin/.test(platform);
    const isLinux = /linux/.test(platform);
    const isIterm = ["iTerm", "iTerm.app", "iTerm2", "iTerm2.app"].includes(terminalApp);
    const isTmux = !!process.env.TMUX_PANE;
    if (split) {
        if (isTmux) {
            return launchers_1.tmux;
        }
        if (isIterm) {
            return launchers_1.iterm;
        }
    }
    if (isMac) {
        return launchers_1.mac;
    }
    if (isWindows) {
        return launchers_1.windows;
    }
    if (isLinux) {
        return launchers_1.linux;
    }
    throw new utils_1.ErrorMessage(`Could not recognize the OS ${platform}`);
}
function launchTerminal(execFilePath, options) {
    const launcher = chooseLauncher(options);
    launcher(execFilePath, options);
}
exports.default = launchTerminal;
//# sourceMappingURL=launchTerminal.js.map